@@ -1631,18 +1631,22 @@ static int wp_tdmv_rbsbits(struct zt_chan *chan, int bits)
 	wp_tdmv_softc_t	*wp = NULL;
 	sdla_t		*card = NULL;
 	unsigned char	ABCD_bits = 0x00;
+	wan_smp_flag_t smp_flags;
 	
 	/* Byte offset */
 	WAN_ASSERT2(chan == NULL, 0);
 	if ((wp = chan->pvt) == NULL) return 0;
 	WAN_ASSERT2(wp->card == NULL, 0);
 	card = (sdla_t*)wp->card;
+
 	if (!wan_test_bit(chan->chanpos-1, &wp->timeslot_map)){
 		return 0;	
 	}
-   	if (!wan_test_bit(WP_TDMV_SIG_ENABLE, &wp->flags)){
+   	
+	if (!wan_test_bit(WP_TDMV_SIG_ENABLE, &wp->flags)){
                 return 0;
-        }
+    }
+
 	if (bits & ZT_ABIT) ABCD_bits |= WAN_RBS_SIG_A;
 	if (bits & ZT_BBIT) ABCD_bits |= WAN_RBS_SIG_B;
 	if (bits & ZT_CBIT) ABCD_bits |= WAN_RBS_SIG_C;
@@ -1661,41 +1665,16 @@ static int wp_tdmv_rbsbits(struct zt_chan *chan, int bits)
 			(ABCD_bits & WAN_RBS_SIG_C) ? 1 : 0,
 			(ABCD_bits & WAN_RBS_SIG_D) ? 1 : 0);
 
-	if (wan_test_and_set_bit(chan->chanpos-1, &wp->rbs_tx_status)){
-		if (ABCD_bits == wp->rbs_tx[chan->chanpos-1]){
-			return 0;
-		}
-		if (wan_test_and_set_bit(chan->chanpos-1, &wp->rbs_tx1_status)){
-			if (ABCD_bits == wp->rbs_tx1[chan->chanpos-1]){
-				return 0;
-			}
-			DEBUG_EVENT("%s: Critical Error: TX RBS for channel %d\n",
-						wp->devname,
-						chan->chanpos);
-		}
-		wp->rbs_tx1[chan->chanpos-1] = ABCD_bits;
-	}else{
-		wp->rbs_tx[chan->chanpos-1] = ABCD_bits;
-	}
-#if 0
-	wan_set_bit(7, &ABCD_bits);
-	if (wan_test_and_set_bit(7, &wp->rbs_tx[chan->chanpos-1])){
-		if (ABCD_bits == wp->rbs_tx[chan->chanpos-1]){
-			return 0;
-		}
-		if (wan_test_and_set_bit(7, &wp->rbs_tx1[chan->chanpos-1])){
-			if (ABCD_bits == wp->rbs_tx1[chan->chanpos-1]){
-				return 0;
-			}
-			DEBUG_EVENT("%s: Critical Error: TX RBS for channel %d\n",
-						wp->devname,
-						chan->chanpos);
-		}
-		wp->rbs_tx1[chan->chanpos-1] = ABCD_bits;
-	}else{
-		wp->rbs_tx[chan->chanpos-1] = ABCD_bits;
-	}
-#endif
+
+	 card->hw_iface.hw_lock(card->hw,&smp_flags);
+	 if (card->wandev.fe_iface.set_rbsbits) {
+     	card->wandev.fe_iface.set_rbsbits(
+					&wp->card->fe, 
+					chan->chanpos, 
+					ABCD_bits);  
+	 }
+	 card->hw_iface.hw_unlock(card->hw,&smp_flags);
+
 	return 0;
 }
 
